CallErrorCode class

Constructors

CallErrorCode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

AnsweredElsewhere ↔ String
A different device answered the call
getter/setter pair
CreateAnswer ↔ String
An answer could not be created
getter/setter pair
IceFailed ↔ String
No media connection could be established to the other party
getter/setter pair
InviteTimeout ↔ String
The invite timed out whilst waiting for an answer
getter/setter pair
LocalOfferFailed ↔ String
An error code when the local client failed to create an offer.
getter/setter pair
NoUserMedia ↔ String
An error code when there is no local mic/camera to use. This may be because the hardware isn't plugged in, or the user has explicitly denied access.
getter/setter pair
Replaced ↔ String
The call was replaced by another call
getter/setter pair
SendAnswer ↔ String
Error code used when we fail to send the answer for some reason other than there being unknown devices
getter/setter pair
SendInvite ↔ String
Error code used when we fail to send the invite for some reason other than there being unknown devices
getter/setter pair
SetLocalDescription ↔ String
The session description from this side could not be set
getter/setter pair
SetRemoteDescription ↔ String
The session description from the other side could not be set
getter/setter pair
SignallingFailed ↔ String
Signalling for the call could not be sent (other than the initial invite)
getter/setter pair
Transfered ↔ String
We transferred the call off to somewhere else
getter/setter pair
UnknownDevices ↔ String
Error code used when a call event failed to send because unknown devices were present in the room
getter/setter pair
UserBusy ↔ String
The remote party is busy
getter/setter pair
UserHangup ↔ String
The user chose to end the call
getter/setter pair