CallOptions class

Initialization parameters of the call session.

Constructors

CallOptions()

Properties

callId ↔ String
getter/setter pair
dir ↔ CallDirection
getter/setter pair
groupCallId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iceServers ↔ List<Map<String, dynamic>>
getter/setter pair
localPartyId ↔ String
getter/setter pair
room ↔ Room
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ CallType
getter/setter pair
voip ↔ VoIP
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited