CallReplacesTarget class

Constructors

CallReplacesTarget({String? id, String? display_name, String? avatar_url})
CallReplacesTarget.fromJson(Map<String, dynamic> json)
factory

Properties

avatar_url ↔ String?
getter/setter pair
display_name ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited