DeviceKeys class

Inheritance

Constructors

DeviceKeys.fromDb(Map<String, dynamic> dbEntry, Client client)
DeviceKeys.fromJson(Map<String, dynamic> json, Client client)
DeviceKeys.fromSDNDeviceKeys(SDNDeviceKeys keys, Client client, [DateTime? lastActiveTs])

Properties

algorithms ↔ List<String>
getter/setter pair
blocked ↔ bool
getter/setter pairinherited-setteroverride-getter
client ↔ Client
getter/setter pairinherited
crossVerified → bool
no setterinherited
curve25519Key → String?
no setter
deviceDisplayName → String?
no setter
deviceId → String?
no setter
directVerified → bool
no setterinherited
ed25519Key → String?
no setterinherited
encryptToDevice → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ String?
getter/setter pairoverride-getter
isValid → bool
no setter
keys ↔ Map<String, String>
getter/setter pairinherited
lastActive ↔ DateTime
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfSigned → bool
no setter
signatures ↔ Map<String, Map<String, String>>?
getter/setter pairinherited
signed → bool
no setterinherited
signingContent → String
no setterinherited
unsigned ↔ Map<String, Object?>?
getter/setter pairinherited
userId ↔ String
getter/setter pairinherited
validSignatures ↔ Map<String, dynamic>?
getter/setter pairinherited
verified → bool
no setterinherited

Methods

cloneForSigning() → SimpleSignableKey
inherited
hasValidSignatureChain({bool verifiedOnly = true, Set<String>? visited, Set<String>? onlyValidateUserIds, bool verifiedByTheirMasterKey = false}) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBlocked(bool newBlocked) → Future<void>
override
setDirectVerified(bool isVerified) → void
inherited
setVerified(bool newVerified, [bool sign = true]) → Future<void>
override
startVerification() → KeyVerification
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
inherited