EncryptedFile class

Available extensions

Constructors

EncryptedFile({required Uint8List data, required String k, required String iv, required String sha256})

Properties

data ↔ Uint8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iv ↔ String
getter/setter pair
k ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256 ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSDNFile() → SDNFile

Available on EncryptedFile, provided by the ToSDNFile extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited