EventStatus enum

Defines event status:

  • removed
  • error: (http request failed)
  • sending: (http request started)
  • sent: (http request successful)
  • synced: (event came from sync loop)
  • roomState
Inheritance
Available extensions

Values

removed → const EventStatus
error → const EventStatus
sending → const EventStatus
sent → const EventStatus
synced → const EventStatus
roomState → const EventStatus

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
intValue → int

Available on EventStatus, provided by the EventStatusExtension extension

Returns int value of the event status.
no setter
isError → bool

Available on EventStatus, provided by the EventStatusExtension extension

Return true if the EventStatus equals error.
no setter
isRemoved → bool

Available on EventStatus, provided by the EventStatusExtension extension

Return true if the EventStatus equals removed.
no setter
isRoomState → bool

Available on EventStatus, provided by the EventStatusExtension extension

Return true if the EventStatus equals roomState.
no setter
isSending → bool

Available on EventStatus, provided by the EventStatusExtension extension

Return true if the EventStatus equals sending.
no setter
isSent → bool

Available on EventStatus, provided by the EventStatusExtension extension

Returns true if the status is sent or later: EventStatus.sent, EventStatus.synced or EventStatus.roomState.
no setter
isSynced → bool

Available on EventStatus, provided by the EventStatusExtension extension

Returns true if the status is synced or roomState: EventStatus.synced or EventStatus.roomState.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EventStatus>
A constant List of the values in this enum, in order of their declaration.