EventUpdate class

Represents a new event (e.g. a message in a room) or an update for an already known event.

Constructors

EventUpdate({required String roomID, required EventUpdateType type, required Map<String, dynamic> content})

Properties

content → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
roomID → String
Most events belong to a room. If not, this equals to eventType.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → EventUpdateType
Usually 'timeline', 'state' or whatever.
final

Methods

decrypt(Room room, {bool store = false}) → Future<EventUpdate>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited