FieldType class

Definition of valid values for a field.

Constructors

FieldType({required String placeholder, required String regexp})
FieldType.fromJson(Map<String, Object?> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
placeholder ↔ String
An placeholder serving as a valid example of the field value.
getter/setter pair
regexp ↔ String
A regular expression for validation of a field's value. This may be relatively coarse to verify the value as the application service providing this protocol may apply additional validation or filtering.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited