FileTooBigSDNException class

Inheritance

Constructors

FileTooBigSDNException(int actualFileSize, int maxFileSize)

Properties

actualFileSize ↔ int
getter/setter pair
authenticationFlows → List<AuthenticationFlow>?
For each endpoint, a server offers one or more 'flows' that the client can use to authenticate itself. Each flow comprises a series of stages. If this request doesn't need additional authentication, then this is null.
no setterinherited
authenticationParams → Map<String, Object?>?
This section contains any information that the client will need to know in order to use a given type of authentication. For each authentication type presented, that type may be present as a key in this dictionary. For example, the public part of an OAuth client ID could be given here.
no setterinherited
completedAuthenticationFlows → List<String>
Returns the list of already completed authentication flows from previous requests.
no setterinherited
errcode → String
The unique identifier for this error.
no setterinherited
error → SDNError
Returns the errcode as an SDNError.
no setterinherited
errorMessage → String
A human readable error description.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
maxFileSize ↔ int
getter/setter pair
raw → Map<String, Object?>
finalinherited
requireAdditionalAuthentication → bool
Returns true if the server requires additional authentication.
no setterinherited
response ↔ Response?
The frozen request which triggered this Error
getter/setter pairinherited
retryAfterMs → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → String?
This is a session identifier that the client must pass back to the node, if one is provided, in subsequent attempts to authenticate in the same API call.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited