Filter class

Constructors

Filter({EventFilter? accountData, List<String>? eventFields, EventFormat? eventFormat, EventFilter? presence, RoomFilter? room})
Filter.fromJson(Map<String, Object?> json)

Properties

accountData ↔ EventFilter?
The user account data that isn't associated with rooms to include.
getter/setter pair
eventFields ↔ List<String>?
List of event fields to include. If this list is absent then all fields are included. The entries may include '.' characters to indicate sub-fields. So 'content.body' will include the 'body' field of the 'content' object. A literal '.' character in a field name may be escaped using a '\'. A server may include more fields than were requested.
getter/setter pair
eventFormat ↔ EventFormat?
The format to use for events. 'client' will return the events in a format suitable for clients. 'federation' will return the raw event as received over federation. The default is 'client'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
presence ↔ EventFilter?
The presence updates to include.
getter/setter pair
room ↔ RoomFilter?
Filters to be applied to room data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited