ForwardedRoomKeyContent class

Inheritance

Properties

algorithm ↔ String
getter/setter pairinherited
forwardingCurve25519KeyChain ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
roomId ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderClaimedEd25519Key ↔ String
getter/setter pair
senderKey ↔ String
getter/setter pair
sessionId ↔ String
getter/setter pairinherited
sessionKey ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited