GroupCallEvent class

Constructors

GroupCallEvent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ActiveSpeakerChanged ↔ String
getter/setter pair
CallsChanged ↔ String
getter/setter pair
Error ↔ String
getter/setter pair
GroupCallStateChanged ↔ String
getter/setter pair
LocalMuteStateChanged ↔ String
getter/setter pair
LocalScreenshareStateChanged ↔ String
getter/setter pair
ParticipantsChanged ↔ String
getter/setter pair
ScreenshareStreamsChanged ↔ String
getter/setter pair
UserMediaStreamsChanged ↔ String
getter/setter pair