LoginType enum

Inheritance
Available extensions
Annotations
  • @EnhancedEnum.new()

Values

mLoginPassword → const LoginType
mLoginToken → const LoginType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isMLoginPassword → bool

Available on LoginType, provided by the LoginTypeEnhancedEnum extension

no setter
isMLoginToken → bool

Available on LoginType, provided by the LoginTypeEnhancedEnum extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on LoginType, provided by the LoginTypeEnhancedEnum extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<T>({T? mLoginPassword()?, T? mLoginToken()?, required T orElse()}) → T

Available on LoginType, provided by the LoginTypeEnhancedEnum extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<T>({required T mLoginPassword(), required T mLoginToken()}) → T

Available on LoginType, provided by the LoginTypeEnhancedEnum extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LoginType>
A constant List of the values in this enum, in order of their declaration.