PublicRoomQueryFilter class

Constructors

PublicRoomQueryFilter({String? genericSearchTerm, List<String>? roomTypes})
PublicRoomQueryFilter.fromJson(Map<String, Object?> json)

Properties

genericSearchTerm ↔ String?
An optional string to search for in the room metadata, e.g. name, topic, canonical alias, etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
roomTypes ↔ List<String>?
An optional list of room types to search for. To include rooms without a room type, specify null within this list. When not specified, all applicable rooms (regardless of type) are returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited