PushNotification class

Push Notification object from https://spec.sdn.org/v1.2/push-gateway-api/

Constructors

PushNotification({Map<String, dynamic>? content, PushNotificationCounts? counts, required List<PushNotificationDevice> devices, String? eventId, String? prio, String? roomAlias, String? roomId, String? roomName, String? sender, String? senderDisplayName, String? type})
const
PushNotification.fromJson(Map<String, dynamic> json)
Generate a Push Notification object from JSON. It also supports a <String, String> map which usually comes from Firebase Cloud Messaging.
factory

Properties

content → Map<String, dynamic>?
final
counts → PushNotificationCounts?
final
devices → List<PushNotificationDevice>
final
eventId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
prio → String?
final
roomAlias → String?
final
roomId → String?
final
roomName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String?
final
senderDisplayName → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited