PushNotificationDevice class

Constructors

PushNotificationDevice({required String appId, Map<String, dynamic>? data, required String pushkey, int? pushkeyTs, Tweaks? tweaks})
const
PushNotificationDevice.fromJson(Map<String, dynamic> json)
factory

Properties

appId → String
final
data → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
pushkey → String
final
pushkeyTs → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tweaks → Tweaks?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited