ReceiptType enum

Inheritance
Available extensions
Annotations
  • @EnhancedEnum.new()

Values

mFullyRead → const ReceiptType
mRead → const ReceiptType
mReadPrivate → const ReceiptType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isMFullyRead → bool

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

no setter
isMRead → bool

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

no setter
isMReadPrivate → bool

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<T>({T? mFullyRead()?, T? mRead()?, T? mReadPrivate()?, required T orElse()}) → T

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<T>({required T mFullyRead(), required T mRead(), required T mReadPrivate()}) → T

Available on ReceiptType, provided by the ReceiptTypeEnhancedEnum extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ReceiptType>
A constant List of the values in this enum, in order of their declaration.