RoomEventFilter class

Constructors

RoomEventFilter({bool? containsUrl, bool? includeRedundantMembers, bool? lazyLoadMembers, List<String>? notRooms, List<String>? rooms, bool? unreadThreadNotifications})
RoomEventFilter.fromJson(Map<String, Object?> json)

Properties

containsUrl ↔ bool?
If true, includes only events with a url key in their content. If false, excludes those events. If omitted, url key is not considered for filtering.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeRedundantMembers ↔ bool?
If true, sends all membership events for all events, even if they have already been sent to the client. Does not apply unless lazy_load_members is true. See Lazy-loading room members for more information. Defaults to false.
getter/setter pair
lazyLoadMembers ↔ bool?
If true, enables lazy-loading of membership events. See Lazy-loading room members for more information. Defaults to false.
getter/setter pair
notRooms ↔ List<String>?
A list of room IDs to exclude. If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the 'rooms' filter.
getter/setter pair
rooms ↔ List<String>?
A list of room IDs to include. If this list is absent then all rooms are included.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadThreadNotifications ↔ bool?
If true, enables per-thread notification counts. Only applies to the /sync endpoint. Defaults to false.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited