RoomFilter class

Constructors

RoomFilter({StateFilter? accountData, StateFilter? ephemeral, bool? includeLeave, List<String>? notRooms, List<String>? rooms, StateFilter? state, StateFilter? timeline})
RoomFilter.fromJson(Map<String, Object?> json)

Properties

accountData ↔ StateFilter?
The per user account data to include for rooms.
getter/setter pair
ephemeral ↔ StateFilter?
The ephemeral events to include for rooms. These are the events that appear in the ephemeral property in the /sync response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeLeave ↔ bool?
Include rooms that the user has left in the sync, default false
getter/setter pair
notRooms ↔ List<String>?
A list of room IDs to exclude. If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the 'rooms' filter. This filter is applied before the filters in ephemeral, state, timeline or account_data
getter/setter pair
rooms ↔ List<String>?
A list of room IDs to include. If this list is absent then all rooms are included. This filter is applied before the filters in ephemeral, state, timeline or account_data
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ StateFilter?
The state events to include for rooms.
getter/setter pair
timeline ↔ StateFilter?
The message and state update events to include for rooms.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited