RoomVersionAvailable enum

The stability of the room version.

Inheritance
Available extensions
Annotations
  • @EnhancedEnum.new()

Values

stable → const RoomVersionAvailable
unstable → const RoomVersionAvailable

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isStable → bool

Available on RoomVersionAvailable, provided by the RoomVersionAvailableEnhancedEnum extension

no setter
isUnstable → bool

Available on RoomVersionAvailable, provided by the RoomVersionAvailableEnhancedEnum extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on RoomVersionAvailable, provided by the RoomVersionAvailableEnhancedEnum extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<T>({T? stable()?, T? unstable()?, required T orElse()}) → T

Available on RoomVersionAvailable, provided by the RoomVersionAvailableEnhancedEnum extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<T>({required T stable(), required T unstable()}) → T

Available on RoomVersionAvailable, provided by the RoomVersionAvailableEnhancedEnum extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RoomVersionAvailable>
A constant List of the values in this enum, in order of their declaration.