SDNFile class

Implementers

Constructors

SDNFile({required Uint8List bytes, required String name, String? mimeType})
SDNFile.fromMimeType({required Uint8List bytes, required String name, String? mimeType})
derivatives the MIME type from the bytes and correspondingly creates a SDNFile, SDNImageFile, SDNAudioFile or a SDNVideoFile
factory

Properties

bytes → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
info → Map<String, dynamic>
no setter
mimeType → String
final
msgType → String
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter

Methods

encrypt() → Future<EncryptedFile>
Encrypts this file and returns the encryption information as an EncryptedFile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

msgTypeFromMime(String mimeType) → String