SignableKey class abstract

Inheritance
Implementers

Constructors

SignableKey.fromJson(Map<String, dynamic> json, Client client)

Properties

blocked ↔ bool
getter/setter pair
client ↔ Client
getter/setter pair
crossVerified → bool
no setter
directVerified → bool
no setter
ed25519Key → String?
no setter
encryptToDevice → bool
no setter
hashCode → int
The hash code for this object.
no setteroverride
identifier → String?
no setterinherited
keys ↔ Map<String, String>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures ↔ Map<String, Map<String, String>>?
getter/setter pairinherited
signed → bool
no setter
signingContent → String
no setter
unsigned ↔ Map<String, Object?>?
getter/setter pairinherited
userId ↔ String
getter/setter pairinherited
validSignatures ↔ Map<String, dynamic>?
getter/setter pair
verified → bool
no setter

Methods

cloneForSigning() → SimpleSignableKey
hasValidSignatureChain({bool verifiedOnly = true, Set<String>? visited, Set<String>? onlyValidateUserIds, bool verifiedByTheirMasterKey = false}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBlocked(bool newBlocked) → Future<void>
setDirectVerified(bool isVerified) → void
setVerified(bool newVerified, [bool sign = true]) → Future<void>
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(dynamic other) → bool
The equality operator.
override