SimpleSignableKey class

Inheritance

Constructors

SimpleSignableKey.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ String?
getter/setter pairoverride-getter
keys ↔ Map<String, String>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures ↔ Map<String, Map<String, String>>?
getter/setter pairinherited
unsigned ↔ Map<String, Object?>?
getter/setter pairinherited
userId ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited