StateFilter class

Implemented types

Constructors

StateFilter({int? limit, List<String>? notSenders, List<String>? notTypes, List<String>? senders, List<String>? types, bool? containsUrl, bool? includeRedundantMembers, bool? lazyLoadMembers, List<String>? notRooms, List<String>? rooms, bool? unreadThreadNotifications})
StateFilter.fromJson(Map<String, Object?> json)

Properties

containsUrl ↔ bool?
If true, includes only events with a url key in their content. If false, excludes those events. If omitted, url key is not considered for filtering.
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
includeRedundantMembers ↔ bool?
If true, sends all membership events for all events, even if they have already been sent to the client. Does not apply unless lazy_load_members is true. See Lazy-loading room members for more information. Defaults to false.
getter/setter pairoverride
lazyLoadMembers ↔ bool?
If true, enables lazy-loading of membership events. See Lazy-loading room members for more information. Defaults to false.
getter/setter pairoverride
limit ↔ int?
The maximum number of events to return.
getter/setter pairoverride
notRooms ↔ List<String>?
A list of room IDs to exclude. If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the 'rooms' filter.
getter/setter pairoverride
notSenders ↔ List<String>?
A list of sender IDs to exclude. If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the 'senders' filter.
getter/setter pairoverride
notTypes ↔ List<String>?
A list of event types to exclude. If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the 'types' filter. A '*' can be used as a wildcard to match any sequence of characters.
getter/setter pairoverride
rooms ↔ List<String>?
A list of room IDs to include. If this list is absent then all rooms are included.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senders ↔ List<String>?
A list of senders IDs to include. If this list is absent then all senders are included.
getter/setter pairoverride
types ↔ List<String>?
A list of event types to include. If this list is absent then all event types are included. A '*' can be used as a wildcard to match any sequence of characters.
getter/setter pairoverride
unreadThreadNotifications ↔ bool?
If true, enables per-thread notification counts. Only applies to the /sync endpoint. Defaults to false.
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited