WebRTCDelegate class abstract

Delegate WebRTC basic functionality.

Constructors

WebRTCDelegate()

Properties

canHandleNewCall → bool
This should be set to false if any calls in the client are in kConnected state. If another room tries to call you during a connected call this fires a handleMissedCall
no setter
hashCode → int
The hash code for this object.
no setterinherited
isWeb → bool
no setter
mediaDevices → MediaDevices
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPeerConnection(Map<String, dynamic> configuration, [Map<String, dynamic> constraints = const {}]) → Future<RTCPeerConnection>
createRenderer() → VideoRenderer
handleCallEnded(CallSession session) → Future<void>
handleGroupCallEnded(GroupCall groupCall) → Future<void>
handleMissedCall(CallSession session) → Future<void>
handleNewCall(CallSession session) → Future<void>
handleNewGroupCall(GroupCall groupCall) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playRingtone() → Future<void>
stopRingtone() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited